.. _getting-started:

Installation
============

The library requires Python 3.4 or greater. It will not run on Python 2.

The simplest way to install the package is to obtain it from the PyPi
repository::

    $ pip install axelrod


You can also build it from source if you would like to::

    $ git clone https://github.com/Axelrod-Python/Axelrod.git
    $ cd Axelrod
    $ python setup.py install
